/**********************************************************************
* File: Main_12.c -- File for Lab 12
* Devices: TMS320F2833x
* Author: Technical Training Organization (TTO), Texas Instruments
* History:
*   07/15/08 - original
**********************************************************************/

#include "Lab.h"						// Main include file

//--- Global Variables
Uint16 DEBUG_TOGGLE = 1;				// Used in realtime mode investigation - Lab 6
Uint16 DEBUG_FILTER = 1;				// Used to turn filter on/off - Lab 12

_iq AdcBuf[ADC_BUF_LEN];				// ADC data buffer allocation
_iq AdcBufFiltered[ADC_BUF_LEN];		// ADC filtered data buffer allocation
_iq xDelay[FILTER_LEN] = {0,0,0,0,0};	// filter delay chain
_iq coeffs[FILTER_LEN] = {_IQ(0.0625),_IQ(0.25),_IQ(0.375),_IQ(0.25),_IQ(0.0625)};	// filter coefficients

Uint32 PwmDuty;							// measured PWM duty cycle
Uint32 PwmPeriod;						// measured PWM period

long	GlobalQ = GLOBAL_Q;				// IQmath debug support

#pragma DATA_SECTION(AdcBufRaw, "dmaMemBufs");
Uint16 AdcBufRaw[2*ADC_BUF_LEN];			// ADC raw data buffer allocation


/**********************************************************************
* Function: main()
*
* Description: Main function for C28x workshop labs
**********************************************************************/
void main(void)
{
//--- CPU Initialization
	InitSysCtrl();						// Initialize the CPU (FILE: SysCtrl.c)
	InitGpio();							// Initialize the shared GPIO pins (FILE: Gpio.c)
	InitPieCtrl();						// Initialize and enable the PIE (FILE: PieCtrl.c)
	InitWatchdog();						// Initialize the Watchdog Timer (FILE: WatchDog.c)

//--- Copy all Flash sections that need to run from RAM (use memcpy() from RTS library)

// Section secureRamFuncs contains user defined code that runs from CSM secured RAM
	memcpy(&secureRamFuncs_runstart, &secureRamFuncs_loadstart, (Uint32)&secureRamFuncs_loadsize);

//--- Initialize the Flash and OTP
	InitFlash();						// Initialize the Flash (FILE: Flash.c)

//--- Peripheral Initialization
	InitAdc();							// Initialize the ADC (FILE: Adc.c)
	InitEPwm();							// Initialize the EPwm (FILE: EPwm.c) 
	InitECap();							// Initialize the ECap (FILE: ECap.c) 
	InitDma();							// Initialize the DMA (FILE: Dma.c)

//--- Enable global interrupts
	asm(" CLRC INTM, DBGM");					// DSP/BIOS will enable global interrupts (INTM and DBGM)

//--- Main Loop
	while(1)							// while() loop removed to enable DSP/BIOS
	{
		asm(" NOP");
	}


} //end of main()



/**********************************************************************
* Function: UserInit()
*
* Description: This is the user initialization file to be specified in
* the DSP/BIOS configuration file, System - Global Settings.
**********************************************************************/
void UserInit(void)
{

// Section .trcdata is generated by DSP/BIOS.
// It must be copied from its load to its run address BEFORE main().
	memcpy(&trcdata_runstart, &trcdata_loadstart, (Uint32)&trcdata_loadsize);

} // end of UserInit()



/**********************************************************************
* Function: LedBlink()
*
* Description: Blinks LED on F28335 ControlCARD
**********************************************************************/
void LedBlink(void)
{






} // end of LedBlink()



/**********************************************************************
* Function: AdcSwi()
*
* Description: ADC interrupt SWI
**********************************************************************/
void AdcSwi(void)
{






} // end of AdcSwi()



/**********************************************************************
* Function: Dma1Swi()
*
* Description: DMA Ch1 interrupt SWI
**********************************************************************/
void Dma1Swi(void)
{






} // end of Dma1Swi()



/*** end of file *****************************************************/
